@@ -11,7 +11,10 @@ import pytablewriter
 from pytablewriter import MarkdownTableWriter
 from redistimeseries.client import Client
 
-from redisbench_admin.profilers.perf_daemon_caller import PerfDaemonRemoteCaller
+from redisbench_admin.profilers.perf_daemon_caller import (
+    PerfDaemonRemoteCaller,
+    PERF_DAEMON_LOGNAME,
+)
 from redisbench_admin.run.args import PROFILE_FREQ
 from redisbench_admin.run.common import (
     get_start_time_vars,
@@ -22,6 +25,7 @@ from redisbench_admin.run.common import (
 )
 from redisbench_admin.run.git import git_vars_crosscheck
 from redisbench_admin.run.grafana import generate_artifacts_table_grafana_redis
+from redisbench_admin.run.metrics import collect_redis_metrics
 from redisbench_admin.run.modules import redis_modules_check
 from redisbench_admin.run.redistimeseries import (
     timeseries_test_sucess_flow,
@@ -46,6 +50,8 @@ from redisbench_admin.utils.remote import (
     get_run_full_filename,
     get_overall_dashboard_keynames,
     check_ec2_env,
+    get_project_ts_tags,
+    push_data_to_redistimeseries,
 )
 
 from redisbench_admin.utils.utils import (
@@ -57,6 +63,12 @@ from redisbench_admin.utils.utils import (
 )
 
 
+# 7 days expire
+STALL_INFO_DAYS = 7
+EXPIRE_TIME_SECS_PROFILE_KEYS = 60 * 60 * 24 * STALL_INFO_DAYS
+EXPIRE_TIME_MSECS_PROFILE_KEYS = EXPIRE_TIME_SECS_PROFILE_KEYS * 1000
+
+
 def run_remote_command_logic(args, project_name, project_version):
     logging.info(
         "Using: {project_name} {project_version}".format(
@@ -139,7 +151,11 @@ def run_remote_command_logic(args, project_name, project_version):
     allowed_tools = args.allowed_tools
 
     if args.push_results_redistimeseries:
-        logging.info("Checking connection to RedisTimeSeries.")
+        logging.info(
+            "Checking connection to RedisTimeSeries to host: {}:{}".format(
+                args.redistimeseries_host, args.redistimeseries_port
+            )
+        )
         rts = Client(
             host=args.redistimeseries_host,
             port=args.redistimeseries_port,
@@ -457,7 +473,24 @@ def run_remote_command_logic(args, project_name, project_version):
                                         logging.info("Stopping remote profiler")
                                         profiler_result = remote_perf.stop_profile()
                                         if profiler_result is False:
-                                            logging.error("Unsuccessful profiler stop")
+                                            logging.error(
+                                                "Unsuccessful profiler stop."
+                                                + " Fetching remote perf-daemon logfile {}".format(
+                                                    PERF_DAEMON_LOGNAME
+                                                )
+                                            )
+                                            failed_remote_run_artifact_store(
+                                                args.upload_results_s3,
+                                                server_public_ip,
+                                                dirname,
+                                                PERF_DAEMON_LOGNAME,
+                                                logname,
+                                                s3_bucket_name,
+                                                s3_bucket_path,
+                                                username,
+                                                private_key,
+                                            )
+                                            return_code |= 1
                                         (
                                             perf_stop_status,
                                             profile_artifacts,
@@ -497,6 +530,64 @@ def run_remote_command_logic(args, project_name, project_version):
                                                 )
                                             )
 
+                                    if args.push_results_redistimeseries and (
+                                        artifact_version is not None
+                                        or tf_github_branch == "master"
+                                    ):
+                                        (
+                                            end_time_ms,
+                                            _,
+                                            overall_end_time_metrics,
+                                        ) = collect_redis_metrics(
+                                            redis_conns,
+                                            ["memory"],
+                                            {
+                                                "memory": [
+                                                    "used_memory",
+                                                    "used_memory_dataset",
+                                                ]
+                                            },
+                                        )
+                                        expire_ms = 7 * 24 * 60 * 60 * 1000
+                                        export_redis_metrics(
+                                            artifact_version,
+                                            end_time_ms,
+                                            overall_end_time_metrics,
+                                            rts,
+                                            setup_name,
+                                            setup_type,
+                                            test_name,
+                                            tf_github_branch,
+                                            tf_github_org,
+                                            tf_github_repo,
+                                            tf_triggering_env,
+                                            {"metric-type": "redis-metrics"},
+                                            expire_ms,
+                                        )
+                                        if args.collect_commandstats:
+                                            (
+                                                end_time_ms,
+                                                _,
+                                                overall_commandstats_metrics,
+                                            ) = collect_redis_metrics(
+                                                redis_conns, ["commandstats"]
+                                            )
+                                            export_redis_metrics(
+                                                artifact_version,
+                                                end_time_ms,
+                                                overall_commandstats_metrics,
+                                                rts,
+                                                setup_name,
+                                                setup_type,
+                                                test_name,
+                                                tf_github_branch,
+                                                tf_github_org,
+                                                tf_github_repo,
+                                                tf_triggering_env,
+                                                {"metric-type": "commandstats"},
+                                                expire_ms,
+                                            )
+
                                     if setup_details["env"] is None:
                                         if args.keep_env_and_topo is False:
                                             shutdown_remote_redis(
@@ -524,8 +615,8 @@ def run_remote_command_logic(args, project_name, project_version):
 
                                     if remote_run_result is False:
                                         failed_remote_run_artifact_store(
-                                            args,
-                                            client_public_ip,
+                                            args.upload_results_s3,
+                                            server_public_ip,
                                             dirname,
                                             full_logfiles[0],
                                             logname,
@@ -573,6 +664,11 @@ def run_remote_command_logic(args, project_name, project_version):
                                             branch_tt_keyname,
                                             branch_target_table,
                                         ) in branch_target_tables.items():
+                                            if (
+                                                "contains-target"
+                                                not in branch_target_table
+                                            ):
+                                                continue
                                             if (
                                                 branch_target_table["contains-target"]
                                                 is True
@@ -693,10 +789,101 @@ def run_remote_command_logic(args, project_name, project_version):
                 )
                 profile_markdown_str = htmlwriter.dumps()
                 profile_markdown_str = profile_markdown_str.replace("\n", "")
-                rts.redis.set(target_tables_latest_key, profile_markdown_str)
+                rts.redis.setex(
+                    target_tables_latest_key,
+                    EXPIRE_TIME_SECS_PROFILE_KEYS,
+                    profile_markdown_str,
+                )
     exit(return_code)
 
 
+def export_redis_metrics(
+    artifact_version,
+    end_time_ms,
+    overall_end_time_metrics,
+    rts,
+    setup_name,
+    setup_type,
+    test_name,
+    tf_github_branch,
+    tf_github_org,
+    tf_github_repo,
+    tf_triggering_env,
+    metadata_dict=None,
+    expire_ms=0,
+):
+    datapoint_errors = 0
+    datapoint_inserts = 0
+    sprefix = (
+        "ci.benchmarks.redislabs/"
+        + "{triggering_env}/{github_org}/{github_repo}".format(
+            triggering_env=tf_triggering_env,
+            github_org=tf_github_org,
+            github_repo=tf_github_repo,
+        )
+    )
+    logging.info(
+        "Adding a total of {} server side metrics collected at the end of benchmark".format(
+            len(list(overall_end_time_metrics.items()))
+        )
+    )
+    timeseries_dict = {}
+    by_variants = {}
+    if tf_github_branch is not None and tf_github_branch != "":
+        by_variants["by.branch/{}".format(tf_github_branch)] = {
+            "branch": tf_github_branch
+        }
+    if artifact_version is not None and artifact_version != "":
+        by_variants["by.version/{}".format(artifact_version)] = {
+            "version": artifact_version
+        }
+    for (
+        by_variant,
+        variant_labels_dict,
+    ) in by_variants.items():
+        for (
+            metric_name,
+            metric_value,
+        ) in overall_end_time_metrics.items():
+            tsname_metric = "{}/{}/{}/benchmark_end/{}".format(
+                sprefix,
+                test_name,
+                by_variant,
+                metric_name,
+            )
+
+            logging.debug(
+                "Adding a redis server side metric collected at the end of benchmark."
+                + " metric_name={} metric_value={} time-series name: {}".format(
+                    metric_name,
+                    metric_value,
+                    tsname_metric,
+                )
+            )
+            variant_labels_dict["test_name"] = test_name
+            variant_labels_dict["metric"] = metric_name
+            if metadata_dict is not None:
+                variant_labels_dict.update(metadata_dict)
+
+            timeseries_dict[tsname_metric] = {
+                "labels": get_project_ts_tags(
+                    tf_github_org,
+                    tf_github_repo,
+                    setup_name,
+                    setup_type,
+                    tf_triggering_env,
+                    variant_labels_dict,
+                    None,
+                    None,
+                ),
+                "data": {end_time_ms: metric_value},
+            }
+    i_errors, i_inserts = push_data_to_redistimeseries(rts, timeseries_dict, expire_ms)
+    datapoint_errors = datapoint_errors + i_errors
+    datapoint_inserts = datapoint_inserts + i_inserts
+    return datapoint_errors, datapoint_inserts
+
+
 def shutdown_remote_redis(redis_conns, ssh_tunnel):
     logging.info("Shutting down remote redis.")
     for conn in redis_conns:
