@@ -504,7 +504,7 @@ def fetch_remote_setup_from_config(
     return terraform_working_dir, setup_type, setup
 
 
-def push_data_to_redistimeseries(rts, time_series_dict: dict):
+def push_data_to_redistimeseries(rts, time_series_dict: dict, expire_msecs=0):
     datapoint_errors = 0
     datapoint_inserts = 0
     if rts is not None and time_series_dict is not None:
@@ -512,13 +512,29 @@ def push_data_to_redistimeseries(rts, time_series_dict: dict):
             exporter_create_ts(rts, time_series, timeseries_name)
             for timestamp, value in time_series["data"].items():
                 try:
-                    rts.add(
-                        timeseries_name,
-                        timestamp,
-                        value,
-                        duplicate_policy="last",
-                    )
+                    if timestamp is None:
+                        logging.warning("The provided timestamp is null. Using auto-ts")
+                        rts.add(
+                            timeseries_name,
+                            value,
+                            duplicate_policy="last",
+                        )
+                    else:
+                        rts.add(
+                            timeseries_name,
+                            timestamp,
+                            value,
+                            duplicate_policy="last",
+                        )
                     datapoint_inserts += 1
+                except redis.exceptions.DataError:
+                    logging.warning(
+                        "Error while inserting datapoint ({} : {}) in timeseries named {}. ".format(
+                            timestamp, value, timeseries_name
+                        )
+                    )
+                    datapoint_errors += 1
+                    pass
                 except redis.exceptions.ResponseError:
                     logging.warning(
                         "Error while inserting datapoint ({} : {}) in timeseries named {}. ".format(
@@ -527,33 +543,57 @@ def push_data_to_redistimeseries(rts, time_series_dict: dict):
                     )
                     datapoint_errors += 1
                     pass
+            if expire_msecs > 0:
+                rts.redis.pexpire(timeseries_name, expire_msecs)
     return datapoint_errors, datapoint_inserts
 
 
 def exporter_create_ts(rts, time_series, timeseries_name):
+    updated_create = False
     try:
-        logging.info(
-            "Creating timeseries named {} with labels {}".format(
-                timeseries_name, time_series["labels"]
-            )
-        )
-        rts.create(timeseries_name, labels=time_series["labels"])
-    except redis.exceptions.ResponseError:
-        logging.info(
-            "Timeseries named {} already exists. Checking that the labels match.".format(
-                timeseries_name
-            )
-        )
-        set1 = set(time_series["labels"].items())
-        set2 = set(rts.info(timeseries_name).labels.items())
-        if len(set1 - set2) > 0 or len(set2 - set1) > 0:
-            logging.info(
-                "Given the labels don't match using TS.ALTER on {} to update labels to {}".format(
+        if rts.redis.exists(timeseries_name):
+            updated_create = check_rts_labels(rts, time_series, timeseries_name)
+        else:
+            logging.debug(
+                "Creating timeseries named {} with labels {}".format(
                     timeseries_name, time_series["labels"]
                 )
             )
-            rts.alter(timeseries_name, labels=time_series["labels"])
-        pass
+            rts.create(timeseries_name, labels=time_series["labels"], chunk_size=128)
+            updated_create = True
+
+    except redis.exceptions.ResponseError as e:
+        if "already exists" in e.__str__():
+            updated_create = check_rts_labels(rts, time_series, timeseries_name)
+            pass
+        else:
+            logging.error(
+                "While creating timeseries named {} with the following labels: {} this error ocurred: {}".format(
+                    timeseries_name, time_series["labels"], e.__str__()
+                )
+            )
+            raise
+    return updated_create
+
+
+def check_rts_labels(rts, time_series, timeseries_name):
+    updated_create = False
+    logging.debug(
+        "Timeseries named {} already exists. Checking that the labels match.".format(
+            timeseries_name
+        )
+    )
+    set1 = set(time_series["labels"].items())
+    set2 = set(rts.info(timeseries_name).labels.items())
+    if len(set1 - set2) > 0 or len(set2 - set1) > 0:
+        logging.info(
+            "Given the labels don't match using TS.ALTER on {} to update labels to {}".format(
+                timeseries_name, time_series["labels"]
+            )
+        )
+        updated_create = True
+        rts.alter(timeseries_name, labels=time_series["labels"])
+    return updated_create
 
 
 def extract_redisgraph_version_from_resultdict(results_dict: dict):
@@ -799,9 +839,17 @@ def get_ts_tags_and_name(
         break_by_value, tf_github_repo
     )
     timeserie_tags["test_name"] = str(test_name)
+    if build_variant_name is not None:
+        timeserie_tags["test_name:build_variant"] = "{}:{}".format(
+            test_name, build_variant_name
+        )
     timeserie_tags["metric"] = str(metric_name)
     timeserie_tags["metric_name"] = metric_name
     timeserie_tags["metric_context_path"] = metric_context_path
+    if metric_context_path is not None:
+        timeserie_tags["test_name:metric_context_path"] = "{}:{}".format(
+            test_name, metric_context_path
+        )
     timeserie_tags["metric_jsonpath"] = metric_jsonpath
     if metric_context_path not in testcase_metric_context_paths:
         testcase_metric_context_paths.append(metric_context_path)
